@@ -3,14 +3,14 @@ from .fuse import *
 from .pulse import *
 from .switch import *
 from .eventful_counter import *
-from .async_getch import *
+from .async_std import *
 
 from . import utils
 from . import fuse
 from . import pulse
 from . import switch
 from . import eventful_counter
-from . import async_getch
+from . import async_std
 
 
 __all__ = (  # pyright: ignore
@@ -19,5 +19,5 @@ __all__ = (  # pyright: ignore
     *pulse.__all__,
     *switch.__all__,
     *utils.__all__,
-    *async_getch.__all__,
+    *async_std.__all__,
 )
